@@ -23,9 +23,11 @@ from CsPy_Uploading.functions import save_excel_sheets_to_csv
 from CsPy_Uploading.functions import delete_folder_contents
 from CsPy_Uploading.functions import date_convert
 from CsPy_Uploading.functions import sql_to_workbook
-# TODO: Add int conversion for null values
+
 # TODO: Add better error exceptions
 # TODO: Add function/variable descriptions
+# TODO: Add error handling for miss matched column names
+# TODO: Add Selective Data conversion within date_convert
 
 
 class UploadJob:
@@ -59,6 +61,7 @@ class UploadJob:
         self.data_from = self.get_upload_type()
         self.df = self.get_data_frame()
         self.date_convert()
+        self.int_convert()
 
     def thg_log(self):
         """
@@ -183,6 +186,21 @@ class UploadJob:
         else:
             pass
 
+    def int_convert(self):
+        self.upload_details['Progress'] = 'Converting int columns for upload.'
+        convert_columns = []
+        new_schema = []
+        new_df = self.df
+        for i in self.schema:
+            if i.field_type == 'INTEGER':
+                convert_columns.append(i.name)
+
+        for i in convert_columns:
+            try:
+                new_df[i] = new_df[i].astype('Int64')
+            except Exception as e:
+                self.upload_details['Error'] = e
+
     def get_credentials(self):
         """
         INTERNAL FUNCTION
@@ -294,6 +312,11 @@ class UploadJob:
             self.log('Reading from SQL')
             self.get_dsn()
             self.log('DSN connection: {}'.format(self.dsn))
+            self.query = """
+            set ansi_nulls off 
+            set nocount on 
+            set ansi_warnings off
+            """ + self.query
             connection = odbc.connect(dsn=self.dsn)
             df = pd.read_sql(sql=self.query, con=connection)
             if self.columns is not None:
